@@ -1,7 +1,8 @@
 from .callablegroup import CallableGroup
 from .locked_dataset import LockedDataset
 from .monitor import MonitorList, Monitor, MonitorDict, RMonitor
+from .locked_structure import LockedStructure
 from .thread import TerminableThread, Condition
 
 __all__ = ['LockedDataset', 'Monitor', 'RMonitor', 'CallableGroup', 'TerminableThread',
-           'MonitorDict', 'MonitorList', 'Condition']
+           'MonitorDict', 'MonitorList', 'Condition', 'LockedStructure']
