@@ -1,9 +1,9 @@
 from .choose import choose
 from .iterators import infinite_counter, take_n, is_instance, skip_first, zip_shifted, stop_after, \
     iter_dict_of_list, shift, other_sequence_no_longer_than, count, even, odd
-from .sequences import is_last, add_next, half_product, group_quantity
+from .sequences import is_last, add_next, half_cartesian, group_quantity
 
 __all__ = ['choose', 'infinite_counter', 'take_n', 'is_instance', 'is_last', 'add_next',
-           'half_product', 'skip_first', 'zip_shifted', 'stop_after', 'group_quantity',
+           'half_cartesian', 'skip_first', 'zip_shifted', 'stop_after', 'group_quantity',
            'iter_dict_of_list', 'shift', 'other_sequence_no_longer_than', 'count',
            'even', 'odd']
