@@ -1,6 +1,6 @@
 import typing as tp
 
-__all__ = ['is_last', 'add_next', 'half_product', 'group_quantity']
+__all__ = ['is_last', 'add_next', 'half_cartesian', 'group_quantity']
 T = tp.TypeVar('T')
 U = tp.TypeVar('U')
 
@@ -60,8 +60,7 @@ def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = Fal
             yield prev_val, None
 
 
-def half_product(seq1: tp.Iterable[T], seq2: tp.Iterable[U]) -> tp.Generator[
-    tp.Tuple[T, U], None, None]:
+def half_cartesian(seq1: tp.Iterable[T], include_same_pairs: bool = True) -> tp.Iterator[tp.Tuple[T, T]]:
     """
     Generate half of the Cartesian product of both sequences.
 
@@ -75,11 +74,21 @@ def half_product(seq1: tp.Iterable[T], seq2: tp.Iterable[U]) -> tp.Generator[
 
     :param seq1: First sequence
     :param seq2: Second sequence
+    :param include_same_pairs: if True, then pairs returning two of the same objects will be returned.
+        Ie. if False, the following will be true:
+
+    >>> list(half_cartesian([1, 2, 3], [1, 2, 3], include_same_pairs=False)) == \
+    >>>     [(1, 2), (1, 3), (2, 3)]
+
     """
     for i, elem1 in enumerate(seq1):
-        for j, elem2 in enumerate(seq2):
-            if j >= i:
-                yield elem1, elem2
+        for j, elem2 in enumerate(seq1):
+            if include_same_pairs:
+                if j >= i:
+                    yield elem1, elem2
+            else:
+                if j > i:
+                    yield elem1, elem2
 
 
 def group_quantity(length: int, seq: tp.Iterable[T]) -> tp.Generator[tp.List[T], None, None]:
